betty.project.extension.raspberry_mint.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.raspberry_mint.config module

Provide configuration for the Raspberry Mint extension.

class betty.project.extension.raspberry_mint.config.RaspberryMintConfiguration

  Bases: `Configuration`

  Provide configuration for the `betty.project.extension.raspberry_mint.RaspberryMint` extension.

  DEFAULT_PRIMARY_COLOR = '#b3446c'
  DEFAULT_SECONDARY_COLOR = '#3eb489'
  DEFAULT_TERTIARY_COLOR = '#ffbd22'
  __init__(*, featured_entities: Sequence[EntityReference[UserFacingEntity & Entity]] | None = None, primary_color: str = '#b3446c', secondary_color: str = '#3eb489', tertiary_color: str = '#ffbd22')
  dump() → DumpMapping[Dump]

    Produce a serialized data dump of `self`.

  property featured_entities: EntityReferenceSequence[UserFacingEntity & Entity]

    The entities featured on the front page.

  load(dump: Dump) → None

    Load a serialized data dump into `self`.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump is invalid.

  property primary_color: ColorConfiguration

    The primary color.

  property secondary_color: ColorConfiguration

    The secondary color.

  property tertiary_color: ColorConfiguration

    The tertiary color.